==> micronaut-discovery-client-3.2.0-sources.jar: io/micronaut/discovery/eureka/condition/RequiresEurekaCondition.java <==
/*
 * Copyright 2017-2020 original authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.micronaut.discovery.eureka.condition;

import io.micronaut.context.BeanContext;
import io.micronaut.context.condition.Condition;
import io.micronaut.context.condition.ConditionContext;
import io.micronaut.core.value.PropertyResolver;

/**
 * Determines if eureka is enabled.
 *
 * @author James Kleeh
 * @since 1.2.2
 */
public class RequiresEurekaCondition implements Condition {

    @Override
    public boolean matches(ConditionContext context) {
        BeanContext beanContext = context.getBeanContext();
        if (beanContext instanceof PropertyResolver) {
            PropertyResolver propertyResolver = (PropertyResolver) beanContext;
            if (!propertyResolver.containsProperties("eureka.client")) {
                return false;
            }
            return propertyResolver.getProperty("eureka.client.discovery.enabled", Boolean.class, Boolean.TRUE) ||
                    propertyResolver.getProperty("eureka.client.registration.enabled", Boolean.class, Boolean.TRUE);
        }
        return true;
    }
}

==> micronaut-discovery-client-4.3.0-sources.jar: io/micronaut/discovery/eureka/condition/RequiresEurekaCondition.java <==
/*
 * Copyright 2017-2020 original authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.micronaut.discovery.eureka.condition;

import io.micronaut.context.BeanContext;
import io.micronaut.context.condition.Condition;
import io.micronaut.context.condition.ConditionContext;
import io.micronaut.core.value.PropertyResolver;

/**
 * Determines if eureka is enabled.
 *
 * @author James Kleeh
 * @since 1.2.2
 */
public class RequiresEurekaCondition implements Condition {

    @Override
    public boolean matches(ConditionContext context) {
        BeanContext beanContext = context.getBeanContext();
        if (beanContext instanceof PropertyResolver propertyResolver) {
            if (!propertyResolver.containsProperties("eureka.client")) {
                return false;
            }
            return propertyResolver.getProperty("eureka.client.discovery.enabled", Boolean.class, Boolean.TRUE) ||
                    propertyResolver.getProperty("eureka.client.registration.enabled", Boolean.class, Boolean.TRUE);
        }
        return true;
    }
}
